--- loncom/interface/lonstatistics.pm 2002/03/02 23:22:32 1.6
+++ loncom/interface/lonstatistics.pm 2002/03/07 00:28:55 1.10
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
# (Publication Handler
#
-# $Id: lonstatistics.pm,v 1.6 2002/03/02 23:22:32 minaeibi Exp $
+# $Id: lonstatistics.pm,v 1.10 2002/03/07 00:28:55 minaeibi Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -30,7 +30,7 @@
# 5/05,7/09,7/25/01,8/11,9/13,9/26,10/5,10/9,10/22,10/26 Behrouz Minaei
# 11/1, 11/4, 11/16, 12/14, 12/16, 12/18,12/20,12/31 Behrouz Minaei
# YEAR=2002
-# 1/22, 2/1, 2/6, 2/25, 3/2 Behrouz Minaei
+# 1/22, 2/1, 2/6, 2/25, 3/2, 3/6 Behrouz Minaei
###
package Apache::lonstatistics;
@@ -41,7 +41,6 @@ use Apache::lonnet();
use Apache::lonhomework;
use HTML::TokeParser;
use GDBM_File;
-#use Benchmark;
# -------------------------------------------------------------- Module Globals
my %hash;
@@ -52,6 +51,9 @@ my %mapsort;
my %section;
my %StuBox;
my %DiscFac;
+my %DisUp;
+my %DisLow;
+my $UpCnt;
my $CurMap;
my $CurSec;
my $CurStu;
@@ -65,7 +67,6 @@ my $OpSel1;
my $OpSel2;
my $OpSelDis1;
my $OpSelDis2;
-my $CurDis=0;
my $OpSel3;
my $OpSel4;
my $GData;
@@ -77,22 +78,92 @@ my $HWN;
my $P_Order;
my %Header = (0,"Homework Sets Order",1,"#Stdnts",2,"Tries",3,"Mod",
4,"Mean",5,"#YES",6,"#yes",7,"%Wrng",8,"DoDiff",
- 9,"S.D.",10,"Skew.",11,"Map");
-# 11,"Dis.F.",12,"Resourse URL");
+ 9,"S.D.",10,"Skew.",11,"D.F.1st",12,"D.F.2nd");
+#------- Processing upperlist and lowerlist according to each problem
+sub ProcessDisc {
+ my @List = @_;
+ @List = sort (@List);
+ my $Count = $#List+1;
+ my $Prb;
+ my @Dis;
+ my $Slvd=0;
+ my $tmp;
+ my $Sum1=0;
+ my $Sum2=0;
+ my $nIdx=0;
+ my $nStud=0;
+ my %Proc;
+ undef %Proc;
+ while ($nIdx<$Count) {
+ ($Prb,$tmp)=split(/\=/,$List[$nIdx]);
+ @Dis=split(/\+/,$tmp);
+ my $Temp = $Prb;
+ do {
+ $nIdx++;
+ $nStud++;
+ $Sum1 += $Dis[0];
+ $Sum2 += $Dis[1];
+ ($Prb,$tmp)=split(/\=/,$List[$nIdx]);
+ @Dis=split(/\+/,$tmp);
+ } while ( $Prb eq $Temp && $nIdx < $Count );
+# $Proc{$Temp}=($Sum1/$nStud).':'.$nStud;
+ $Proc{$Temp}=($Sum1/$nStud).':'.($Sum2/$nStud);
+# $r->print("$nIdx) $Temp --> ($nStud) $Proc{$Temp} ");
+ $Sum1=0;
+ $Sum2=0;
+ $nStud=0;
+ }
+ return %Proc;
+}
+
+
+#------- Creating Discimination factor
+sub Discriminant {
+ my $Count=0;
+ foreach (keys(%DiscFac)){
+ $Count++;
+ }
+ $UpCnt = int(0.27*$Count);
+ my $low=0;
+ my $up=$Count-$UpCnt;
+ my @UpList=();
+ my @LowList=();
+ $Count=0;
+ foreach my $key (sort(keys(%DiscFac))){
+ $Count++;
+ #$r->print(" $Count) $key = $DiscFac{$key}");
+ if ($low < $UpCnt || $Count > $up) {
+ $low++;
+ my $str=$DiscFac{$key};
+ foreach(split(/\:/,$str)){
+ if ($_) {
+ if ($low<$UpCnt){push(@LowList,$_);}
+ else {push(@UpList,$_);}
+ }
+ }
+ }
+ }
+ %DisUp=&ProcessDisc(@UpList);
+ %DisLow=&ProcessDisc(@LowList);
+}
+
+
sub NumericSort {
$a <=> $b;
}
# ------ Create different Student Report
sub StudentReport {
+
my ($sname,$sdom)=@_;
+
if ( $sname eq 'All Students' ) {
$r->print( '
WARNING:
Please select a student
' );
return;
}
- my $shome=&Apache::lonnet::homeserver( $sname,$sdom );
+ my $shome=&Apache::lonnet::homeserver($sname,$sdom);
my $reply=&Apache::lonnet::reply('dump:'.$sdom.':'.$sname.':'.$cid,$shome );
my %result = ();
my $ResId;
@@ -164,8 +235,7 @@ sub StudentReport {
$Code='U';
$Tries = 0;
$Wrongs = 0;
- $LatestVersion = $result{"version:$Prob"};
-
+ $LatestVersion = $result{"version:$Prob"};
if ( $LatestVersion ) {
for ( my $Version=1; $Version<=$LatestVersion; $Version++ ) {
my $vkeys = $result{"$Version:keys:$Prob"};
@@ -189,7 +259,7 @@ sub StudentReport {
$TempHash{"$Part.Wrongs"} = $Wrongs;
}
}
- }
+ }
for ( my $n = 0; $n < $PartNo; $n++ ) {
my $part = $TempHash{$n};
if ($PtrTry ne '') {$PtrTry .= ',';}
@@ -212,17 +282,18 @@ sub StudentReport {
}
sub CreateTable {
+ my $ColNo=0;
+ foreach (keys(%Header)){
+ $ColNo++;
+ }
my ($Hd, $Hid)=@_;
if ( $Hd == 1 ) {
-# $Hid=~/(\d+)\.(\d+)/;
$r->print(' '.$hash{'title_'.$Hid}.''
-# .' ('.&Apache::lonnet::declutter($hash{'map_id_'.$1}).')'
- );
+ '" target="_blank">'.$hash{'title_'.$Hid}.'');
}
my $Result = "\n".'
';
$Result .= '
P#
'."\n";
- for ( my $nIdx=0; $nIdx < 11; $nIdx++ ) {
+ for ( my $nIdx=0; $nIdx < $ColNo; $nIdx++ ) {
$Result .= '
'.''.'
'."\n";
}
@@ -242,8 +313,6 @@ sub PreStatTable {
"_$ENV{'user.domain'}_$cid\_statistics.db";
my $GraphDB = "/home/httpd/perl/tmp/$ENV{'user.name'}".
"_$ENV{'user.domain'}_$cid\_graph.db";
- my $CachDisFac = "/home/httpd/perl/tmp/$ENV{'user.name'}".
- "_$ENV{'user.domain'}_$cid\_DiscFactor.db";
my $OpSel11='';
my $OpSel12='';
my $OpSel13='';
@@ -270,23 +339,29 @@ sub PreStatTable {
$Ptr .= ''."\n";
$Ptr .= '
'.
- ' #Stdnts: Total Number of Students opened the problem. '.
- ' Tries : Total Number of Tries for solving the problem. '.
- ' Mod : Maximunm Number of Tries for solving the problem. '.
- ' Mean : Average Number of the tries. [ Tries / #Stdnts ] '.
- ' #YES : Number of students solved the problem correctly. '.
- ' #yes : Number of students solved the problem by override. '.
- ' %Wrng : Percentage of students tried to solve the problem but'.
+ ' #Stdnts: Total Number of Students opened the problem. '.
+ ' Tries : Total Number of Tries for solving the problem. '.
+ ' Mod : Maximunm Number of Tries for solving the problem. '.
+ ' Mean : Average Number of the tries. [ Tries / #Stdnts ] '.
+ ' #YES : Number of students solved the problem correctly. '.
+ ' #yes : Number of students solved the problem by override. '.
+ ' %Wrng : Percentage of students tried to solve the problem but'.
' still incorrect. [ 100*((#Stdnts-(#YES+#yes))/#Stdnts) ] '.
-# ' DoDiff : Degree of Difficulty of the problem. [ Tries/(#YES+#yes+0.1) ] '.
- ' DoDiff : Degree of Difficulty of the problem. [ 1 - ((#YES+#yes) / Tries) ] '.
- ' S.D. : Standard Deviation of the tries.'.
+# ' DoDiff : Degree of Difficulty of the problem. [ Tries/(#YES+#yes+0.1) ] '. Kashy formula
+ ' DoDiff : Degree of Difficulty of the problem. [ 1 - ((#YES+#yes) / Tries) ] '. #Gerd formula
+ ' S.D. : Standard Deviation of the tries.'.
'[ sqrt(sum((Xi - Mean)^2)) / (#Stdnts-1)'.
' where Xi denotes every student\'s tries ] '.
- ' Skew. : Skewness of the students tries.'.
- ' [ (sqrt( sum((Xi - Mean)^3) / #Stdnts)) / (S.D.^3) ] '.
-
-# ' Dis.F. : Discrimination Factor. [ Sum of Partial Credits Awarded / Total Number of Tries in %27 upper and lower students]'.
+ ' Skew. : Skewness of the students tries.'.
+ ' [ (sqrt( sum((Xi - Mean)^3) / #Stdnts)) / (S.D.^3) ] '.
+ ' Dis.F. : Discrimination Factor: A Standard for '.
+ 'evaluating the problem according to a Criterion '.
+ ' [Applied Criterion in %27 Upper Students - '.
+ 'Applied the same Criterion in %27 Lower Students] '.
+ ' 1st Criterion for Sorting the Students: '.
+ 'Sum of Partial Credit Awarded / Total Number of Tries '.
+ ' 2nd Criterion for Sorting the Students: '.
+ 'Total number of Correct Answers / Total Number of Tries'.
'